==> openturns_0.12.2.orig.tar.gz: openturns-0.12.2/lib/src/Base/Stat/HistoryStrategy.cxx <==
//                                               -*- C++ -*-
/**
 *  @file  HistoryStrategy.cxx
 *  @brief 
 *
 *  (C) Copyright 2005-2007 EDF-EADS-Phimeca
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 *
 *  @author: $LastChangedBy: dutka $
 *  @date:   $LastChangedDate: 2008-10-31 11:52:04 +0100 (ven 31 oct 2008) $
 *  Id:      $Id: HistoryStrategy.cxx 995 2008-10-31 10:52:04Z dutka $
 */
#include "HistoryStrategy.hxx"

namespace OpenTURNS
{

  namespace Base 
  {

    namespace Stat
    {

      /**
       * @class HistoryStrategy
       */

      CLASSNAMEINIT(HistoryStrategy);

      /* Defaultonstructor */
      HistoryStrategy::HistoryStrategy()
	: Common::TypedInterfaceObject<HistoryStrategyImplementation>(HistoryStrategyImplementation().clone())
      {
	// Nothing to do
      }

      /* Constructor with parameters */
      HistoryStrategy::HistoryStrategy(Implementation & p_implementation)
	: Common::TypedInterfaceObject<HistoryStrategyImplementation>(p_implementation)
      {
	// Nothing to do
      }

      /* Constructor with parameters */
      HistoryStrategy::HistoryStrategy(const HistoryStrategyImplementation & implementation)
	: Common::TypedInterfaceObject<HistoryStrategyImplementation>(implementation.clone())
      {
	// Nothing to do
      }

      /* Store the point according to the strategy */
      void HistoryStrategy::store(const NumericalPoint & point)
      {
	copyOnWrite();
	getImplementation()->store(point);
      }

      /* Reset the history storage through the isInitialized_ flag */
      void HistoryStrategy::reset()
      {
	getImplementation()->reset();
      }

      /* History sample accessor */
      NumericalSample HistoryStrategy::getSample() const
      {
	return getImplementation()->getSample();
      }

      /* String converter */
      String HistoryStrategy::str() const
      {
	OSS oss;
	oss << "class=" << HistoryStrategy::GetClassName()
	    << " implementation=" << getImplementation()->str();
	return oss;
      }

    } /* namespace Stat */
  } /* namespace Base */
} /* namespace OpenTURNS */

==> openturns_0.13.2.orig.tar.gz: openturns-0.13.2/lib/src/Base/Stat/HistoryStrategy.cxx <==
//                                               -*- C++ -*-
/**
 *  @file  HistoryStrategy.cxx
 *  @brief 
 *
 *  (C) Copyright 2005-2010 EDF-EADS-Phimeca
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 *
 *  @author: $LastChangedBy: dutka $
 *  @date:   $LastChangedDate: 2010-02-04 16:44:49 +0100 (jeu. 04 févr. 2010) $
 *  Id:      $Id: HistoryStrategy.cxx 1473 2010-02-04 15:44:49Z dutka $
 */
#include "HistoryStrategy.hxx"

namespace OpenTURNS
{

  namespace Base 
  {

    namespace Stat
    {

      /**
       * @class HistoryStrategy
       */

      CLASSNAMEINIT(HistoryStrategy);

      /* Defaultonstructor */
      HistoryStrategy::HistoryStrategy()
	: Common::TypedInterfaceObject<HistoryStrategyImplementation>(HistoryStrategyImplementation().clone())
      {
	// Nothing to do
      }

      /* Constructor with parameters */
      HistoryStrategy::HistoryStrategy(Implementation & p_implementation)
	: Common::TypedInterfaceObject<HistoryStrategyImplementation>(p_implementation)
      {
	// Nothing to do
      }

      /* Constructor with parameters */
      HistoryStrategy::HistoryStrategy(const HistoryStrategyImplementation & implementation)
	: Common::TypedInterfaceObject<HistoryStrategyImplementation>(implementation.clone())
      {
	// Nothing to do
      }

      /* Store the point according to the strategy */
      void HistoryStrategy::store(const NumericalPoint & point)
      {
	copyOnWrite();
	getImplementation()->store(point);
      }

      /* Reset the history storage through the isInitialized_ flag */
      void HistoryStrategy::reset()
      {
	getImplementation()->reset();
      }

      /* History sample accessor */
      NumericalSample HistoryStrategy::getSample() const
      {
	return getImplementation()->getSample();
      }

      /* String converter */
      String HistoryStrategy::__repr__() const
      {
	OSS oss;
	oss << "class=" << HistoryStrategy::GetClassName()
	    << " implementation=" << getImplementation()->__repr__();
	return oss;
      }



    } /* namespace Stat */
  } /* namespace Base */
} /* namespace OpenTURNS */
